@@ -62,6 +62,7 @@ typedef struct {
   GtkWidget *apply_background_button;
   GtkWidget *revert_font_button;
   GtkWidget *apply_font_button;
+  GtkWidget *install_button;
   GtkWidget *theme_info_icon;
   GtkWidget *theme_error_icon;
   gchar *revert_application_font;
@@ -74,4 +75,7 @@ typedef struct {
   GdkPixbuf *gtk_theme_icon;
   GdkPixbuf *window_theme_icon;
   GdkPixbuf *icon_theme_icon;
+  GtkWidget *style_message_area;
+  GtkWidget *style_message_label;
+  GtkWidget *style_install_button;
 } AppearanceData;
