@@ -57,3 +57,6 @@ gboolean theme_delete (const gchar *name, ThemeType type);
 
 gboolean theme_model_iter_last (GtkTreeModel *model, GtkTreeIter *iter);
 gboolean theme_find_in_model (GtkTreeModel *model, const gchar *name, GtkTreeIter *iter);
+
+void     theme_install_file (GtkWindow *parent, const gchar *path);
+gboolean packagekit_available (void);
